window.receiptToastShown = window.receiptToastShown || false;

if (!window.receiptUploaderInitialized) {
  document.addEventListener("DOMContentLoaded", function () {
    const form = document.getElementById("receiptForm");
    const input = document.getElementById("receiptInput");
    const gallery = document.getElementById("receiptGallery");
    const progressContainer = document.getElementById("progressContainer");
    const progressBar = document.getElementById("progressBar");
    const fileLabel = document.getElementById("fileLabel");

    if (!form || !input || !gallery) return;

    // Zmiana labela po wyborze pliku
    if (input && fileLabel) {
      input.addEventListener("change", function () {
        if (input.files.length > 0) {
          fileLabel.textContent = input.files[0].name;
        } else {
          fileLabel.textContent = "Wybierz zdjęcie paragonu";
        }
      });
    }

    form.addEventListener("submit", function (e) {
      e.preventDefault();

      const file = input.files[0];
      if (!file) {
        showToast("Nie wybrano pliku!", "warning");
        return;
      }

      const formData = new FormData();
      formData.append("receipt", file);

      const xhr = new XMLHttpRequest();
      xhr.open("POST", form.action, true);
      xhr.setRequestHeader("X-Requested-With", "XMLHttpRequest");

      xhr.upload.onprogress = function (e) {
        if (e.lengthComputable) {
          const percent = Math.round((e.loaded / e.total) * 100);
          progressBar.style.width = percent + "%";
          progressBar.textContent = percent + "%";
        }
      };

      xhr.onloadstart = function () {
        progressContainer.style.display = "block";
        progressBar.style.width = "0%";
        progressBar.textContent = "0%";
      };

      xhr.onloadend = function () {
        progressContainer.style.display = "none";
        progressBar.style.width = "0%";
        progressBar.textContent = "";
        input.value = "";

        if (fileLabel) {
          fileLabel.textContent = "Wybierz zdjęcie paragonu";
        }
      };

      xhr.onreadystatechange = function () {
        if (xhr.readyState === XMLHttpRequest.DONE) {
          if (xhr.status === 200) {
            const res = JSON.parse(xhr.responseText);
            if (res.success && res.url) {
              fetch(window.location.href)
                .then(response => response.text())
                .then(html => {
                  const parser = new DOMParser();
                  const doc = parser.parseFromString(html, "text/html");
                  const newGallery = doc.getElementById("receiptGallery");
                  if (newGallery) {
                    gallery.innerHTML = newGallery.innerHTML;

                    lightbox.destroy();
                    lightbox = GLightbox({
                      selector: '.glightbox'
                    });

                    if (!window.receiptToastShown) {
                      showToast("Wgrano paragon", "success");
                      window.receiptToastShown = true;
                    }
                  }
                });
            } else {
              showToast(res.message || "Błąd podczas wgrywania.", "danger");
            }
          } else {
            showToast("Błąd serwera. Spróbuj ponownie.", "danger");
          }
        }
      };

      xhr.send(formData);
    });
  });

  window.receiptUploaderInitialized = true;
}
